@@ -104,9 +104,9 @@ class AppConfiguration:
     """A class containing the configuration data needed to start an app as a service. The configuration data should
     conform to the service's twine schema.
 
-    :param str|None configuration_values: values to configure the app
-    :param str|None configuration_manifest: a manifest of files to configure the app
-    :param str|None children: details of the children the app requires
+    :param str|dict|list|None configuration_values: values to configure the app
+    :param str|dict|octue.resources.Manifest|None configuration_manifest: a manifest of files to configure the app
+    :param str|None|list children: details of the children the app requires
     :param str|None output_location: the path to a cloud directory to save output datasets at
     :return None:
     """
